@@ -9,9 +9,8 @@ import zlib
 from codecs import BOM_UTF16_BE
 from hashlib import md5
 from math import ceil, log
-from warnings import warn
 
-VERSION = __version__ = '0.11.0'
+VERSION = __version__ = '0.12.1'
 
 
 def _to_bytes(item):
@@ -121,11 +120,6 @@ class Stream(Object):
         """
         self.stream.append(b'h')
 
-    def color_space(self, space, stroke=False):
-        """color_space is deprecated, use set_color_space instead."""
-        warn(Stream.color_space.__doc__, DeprecationWarning)
-        self.set_color_space(space, stroke)
-
     def curve_to(self, x1, y1, x2, y2, x3, y3):
         """Add cubic Bézier curve to current path.
 
@@ -243,11 +237,6 @@ class Stream(Object):
         """Move text to next line at ``(x, y)`` distance from previous line."""
         self.stream.append(b' '.join((_to_bytes(x), _to_bytes(y), b'Td')))
 
-    def shading(self, name):
-        """shading is deprecated, use paint_shading instead."""
-        warn(Stream.shading.__doc__, DeprecationWarning)
-        self.paint_shading(name)
-
     def paint_shading(self, name):
         """Paint shape and color shading using shading dictionary ``name``."""
         self.stream.append(b'/' + _to_bytes(name) + b' sh')
@@ -394,16 +383,6 @@ class Stream(Object):
             _to_bytes(a), _to_bytes(b), _to_bytes(c),
             _to_bytes(d), _to_bytes(e), _to_bytes(f), b'Tm')))
 
-    def text_matrix(self, a, b, c, d, e, f):
-        """text_matrix is deprecated, use set_text_matrix instead."""
-        warn(Stream.text_matrix.__doc__, DeprecationWarning)
-        self.set_text_matrix(a, b, c, d, e, f)
-
-    def transform(self, a, b, c, d, e, f):
-        """transform is deprecated, use set_matrix instead."""
-        warn(Stream.transform.__doc__, DeprecationWarning)
-        self.set_matrix(a, b, c, d, e, f)
-
     def show_text(self, text):
         """Show text strings with individual glyph positioning."""
         self.stream.append(b'[' + _to_bytes(text) + b'] TJ')
@@ -488,7 +467,6 @@ class PDF:
 
         #: PDF :class:`Dictionary` containing the PDF’s metadata.
         self.info = Dictionary({})
-        self.add_object(self.info)
 
         #: PDF :class:`Dictionary` containing references to the other objects.
         self.catalog = Dictionary({
@@ -554,6 +532,10 @@ class PDF:
         if identifier not in (False, True, None):
             identifier = _to_bytes(identifier)
 
+        # Add info object if needed
+        if self.info:
+            self.add_object(self.info)
+
         # Write header
         self.write_line(b'%PDF-' + version, output)
         self.write_line(b'%\xf0\x9f\x96\xa4', output)
@@ -599,8 +581,7 @@ class PDF:
                     dict_index += 1
                 else:
                     xref.append((
-                        bool(object_.number), object_.offset,
-                        object_.generation))
+                        bool(object_.number), object_.offset, object_.generation))
             xref.append((1, self.current_position, 0))
 
             field2_size = ceil(log(self.current_position + 1, 256))
@@ -618,16 +599,15 @@ class PDF:
                 'W': Array(xref_lengths),
                 'Size': len(self.objects) + 1,
                 'Root': self.catalog.reference,
-                'Info': self.info.reference,
             }
+            if self.info:
+                extra['Info'] = self.info.reference
             if identifier:
-                data = b''.join(
-                    obj.data for obj in self.objects if obj.free != 'f')
+                data = b''.join(obj.data for obj in self.objects if obj.free != 'f')
                 data_hash = md5(data).hexdigest().encode()
                 if identifier is True:
                     identifier = data_hash
-                extra['ID'] = Array((
-                    String(identifier).data, String(data_hash).data))
+                extra['ID'] = Array((String(identifier).data, String(data_hash).data))
             dict_stream = Stream([xref_stream], extra, compress)
             self.xref_position = dict_stream.offset = self.current_position
             self.add_object(dict_stream)
@@ -654,7 +634,8 @@ class PDF:
             self.write_line(b'<<', output)
             self.write_line(f'/Size {len(self.objects)}'.encode(), output)
             self.write_line(b'/Root ' + self.catalog.reference, output)
-            self.write_line(b'/Info ' + self.info.reference, output)
+            if self.info:
+                self.write_line(b'/Info ' + self.info.reference, output)
             if identifier:
                 data = b''.join(
                     obj.data for obj in self.objects if obj.free != 'f')
